@@ -1,9 +1,8 @@
 use strict;
 use warnings;
 package Alien::Google::GRPC;
-$Alien::Google::GRPC::VERSION = '0.04_02'; # TRIAL
-
-$Alien::Google::GRPC::VERSION = '0.0402';use base qw( Alien::Base );
+$Alien::Google::GRPC::VERSION = '0.01';
+use base qw( Alien::Base );
 
 =head1 NAME
 
@@ -84,9 +83,11 @@ If a build is needed, it can be lengthy. A half hour or more to compile is not u
 
 The following dependencies need to be installed in order for gRPC to build.
 
- $ [sudo] apt-get install build-essential autoconf libtool
- $ [sudo] apt-get install automake curl
  $ [sudo] apt-get install git
+ $ [sudo] apt-get install build-essential autoconf libtool
+ $ [sudo] apt-get install automake curl make g++ unzip pkg-config
+ $ [sudo] apt-get install libgflags-dev libgtest-dev
+ $ [sudo] apt-get install clang libc++-dev
 
 The install information that this module is based on is available here:
 https://github.com/grpc/grpc/blob/master/INSTALL.md
@@ -97,20 +98,6 @@ At this time only Linux builds are supported.
 
 =cut
 
-=head1 AUTHOR
-
-Tom Stall <stall@cpan.org>
-
-=cut
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2017 by Tom Stall.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
 
 =head1 SEE ALSO
 
@@ -118,4 +105,5 @@ L<Alien>, L<Alien::Base>, L<Alien::Build::Manual::AlienUser>
 
 =cut
 
+
 1;
